@@ -16,7 +16,7 @@
 
 
 #if !defined (BSON_INSIDE) && !defined (BSON_COMPILATION)
-#error "Only <bson.h> can be included directly."
+#error "Only <bson/bson.h> can be included directly."
 #endif
 
 
@@ -37,7 +37,7 @@
  *
  * BSON minor version component (e.g. 2 if %BSON_VERSION is 1.2.3)
  */
-#define BSON_MINOR_VERSION (9)
+#define BSON_MINOR_VERSION (14)
 
 
 /**
@@ -45,13 +45,13 @@
  *
  * BSON micro version component (e.g. 3 if %BSON_VERSION is 1.2.3)
  */
-#define BSON_MICRO_VERSION (2)
+#define BSON_MICRO_VERSION (0)
 
 
 /**
  * BSON_PRERELEASE_VERSION:
  *
- * BSON prerelease version component (e.g. rc0 if %BSON_VERSION is 1.2.3-rc0)
+ * BSON prerelease version component (e.g. pre if %BSON_VERSION is 1.2.3-pre)
  */
 #define BSON_PRERELEASE_VERSION ()
 
@@ -60,7 +60,7 @@
  *
  * BSON version.
  */
-#define BSON_VERSION (1.9.2)
+#define BSON_VERSION (1.14.0)
 
 
 /**
@@ -69,7 +69,7 @@
  * BSON version, encoded as a string, useful for printing and
  * concatenation.
  */
-#define BSON_VERSION_S "1.9.2"
+#define BSON_VERSION_S "1.14.0"
 
 
 /**
