@@ -14,19 +14,17 @@
  * limitations under the License.
  */
 
+#include "mongoc/mongoc-prelude.h"
+
 #ifndef MONGOC_CURSOR_PRIVATE_H
 #define MONGOC_CURSOR_PRIVATE_H
 
-#if !defined(MONGOC_COMPILATION)
-#error "Only <mongoc.h> can be included directly."
-#endif
+#include <bson/bson.h>
 
-#include <bson.h>
-
-#include "mongoc-client.h"
-#include "mongoc-buffer-private.h"
-#include "mongoc-rpc-private.h"
-#include "mongoc-server-stream-private.h"
+#include "mongoc/mongoc-client.h"
+#include "mongoc/mongoc-buffer-private.h"
+#include "mongoc/mongoc-rpc-private.h"
+#include "mongoc/mongoc-server-stream-private.h"
 
 
 BSON_BEGIN_DECLS
@@ -119,6 +117,7 @@ typedef struct _mongoc_cursor_response_t {
 
 struct _mongoc_cursor_t {
    mongoc_client_t *client;
+   uint32_t client_generation;
 
    uint32_t server_id;
    bool slave_ok;
